Index: trunk/psLib/test/collections/tst_psSort_01.c
===================================================================
--- trunk/psLib/test/collections/tst_psSort_01.c	(revision 805)
+++ trunk/psLib/test/collections/tst_psSort_01.c	(revision 831)
@@ -10,6 +10,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.5 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-02 23:29:29 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -29,15 +29,15 @@
     // Test A - Create float vectors
     printPositiveTestHeader(stdout,"psSort", "Create float vectors");
-    in = psVectorAlloc(PS_TYPE_FLOAT, 5);
+    in = psVectorAlloc(5, PS_TYPE_F32);
     in->n = 5;
-    out = psVectorAlloc(PS_TYPE_FLOAT, 5);
+    out = psVectorAlloc(5, PS_TYPE_F32);
     out->n = 5;
-    in->vec.f[0] = 7.0f;
-    in->vec.f[1] = 9.0f;
-    in->vec.f[2] = 3.0f;
-    in->vec.f[3] = 1.0f;
-    in->vec.f[4] = 5.0f;
+    in->data.F32[0] = 7.0f;
+    in->data.F32[1] = 9.0f;
+    in->data.F32[2] = 3.0f;
+    in->data.F32[3] = 1.0f;
+    in->data.F32[4] = 5.0f;
     for(int i=0; i<5; i++) {
-        printf("vec[%d] = %f\n", i, in->vec.f[i]);
+        printf("vec[%d] = %f\n", i, in->data.F32[i]);
     }
     printFooter(stdout, "psSort", "Create float vectors", true);
@@ -48,5 +48,5 @@
     out = psSort(out, in);
     for(int i=0; i<5; i++) {
-        printf("vec[%d] = %f\n", i, out->vec.f[i]);
+        printf("vec[%d] = %f\n", i, out->data.F32[i]);
     }
     printFooter(stdout, "psSort", "Sort float vector", true);
Index: trunk/psLib/test/collections/tst_psSort_02.c
===================================================================
--- trunk/psLib/test/collections/tst_psSort_02.c	(revision 805)
+++ trunk/psLib/test/collections/tst_psSort_02.c	(revision 831)
@@ -10,6 +10,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.5 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-02 23:29:29 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -29,15 +29,15 @@
     // Test A - Create float vectors
     printPositiveTestHeader(stdout,"psSort", "Create vectors");
-    in = psVectorAlloc(PS_TYPE_FLOAT, 5);
+    in = psVectorAlloc(5, PS_TYPE_F32);
     in->n = 5;
-    out = psVectorAlloc(PS_TYPE_INT32, 5);
+    out = psVectorAlloc(5, PS_TYPE_F32);
     out->n = 5;
-    in->vec.f[0] = 7.0f;
-    in->vec.f[1] = 9.0f;
-    in->vec.f[2] = 3.0f;
-    in->vec.f[3] = 1.0f;
-    in->vec.f[4] = 5.0f;
+    in->data.F32[0] = 7.0f;
+    in->data.F32[1] = 9.0f;
+    in->data.F32[2] = 3.0f;
+    in->data.F32[3] = 1.0f;
+    in->data.F32[4] = 5.0f;
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %f\n", i, in->vec.f[i]);
+        printf("arr[%d] = %f\n", i, in->data.F32[i]);
     }
     printFooter(stdout, "psSort", "Create vectors", true);
@@ -48,5 +48,5 @@
     out = psSortIndex(out, in);
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %d\n", i, out->vec.i32[i]);
+        printf("arr[%d] = %d\n", i, out->data.S32[i]);
     }
     printFooter(stdout, "psSort", "Create sorted index vector", true);
Index: trunk/psLib/test/collections/tst_psSort_03.c
===================================================================
--- trunk/psLib/test/collections/tst_psSort_03.c	(revision 805)
+++ trunk/psLib/test/collections/tst_psSort_03.c	(revision 831)
@@ -10,6 +10,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.5 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-02 23:29:29 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -29,11 +29,11 @@
     // Test A - Create float vectors
     printPositiveTestHeader(stdout,"psSort", "Create float vectors of different sizes");
-    in = psVectorAlloc(PS_TYPE_FLOAT, 5);
+    in = psVectorAlloc(5, PS_TYPE_F32);
     in->n = 5;
-    out = psVectorAlloc(PS_TYPE_FLOAT, 6);
+    out = psVectorAlloc(6, PS_TYPE_F32);
     out->n = 6;
     in->n = 5;
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %f\n", i, in->vec.f[i]);
+        printf("arr[%d] = %f\n", i, in->data.F32[i]);
     }
     printFooter(stdout, "psSort", "Create float vectors of different sizes", true);
Index: trunk/psLib/test/collections/tst_psSort_04.c
===================================================================
--- trunk/psLib/test/collections/tst_psSort_04.c	(revision 805)
+++ trunk/psLib/test/collections/tst_psSort_04.c	(revision 831)
@@ -10,6 +10,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.5 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-02 23:29:29 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -25,6 +25,6 @@
     psVector *badIn = NULL;
     psVector *badOut = NULL;
-    psVector *goodIn = psVectorAlloc(PS_TYPE_FLOAT, 5);
-    psVector *goodOut = psVectorAlloc(PS_TYPE_FLOAT, 5);
+    psVector *goodIn = psVectorAlloc(5, PS_TYPE_F32);
+    psVector *goodOut = psVectorAlloc(5, PS_TYPE_F32);
 
     // Test A - Attempt to sort with null input vector
Index: trunk/psLib/test/collections/tst_psVector_02.c
===================================================================
--- trunk/psLib/test/collections/tst_psVector_02.c	(revision 805)
+++ trunk/psLib/test/collections/tst_psVector_02.c	(revision 831)
@@ -12,6 +12,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-02 23:29:29 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -39,5 +39,5 @@
     // Test A - Create void pointer vector
     printPositiveTestHeader(stdout,"psVector", "Create void pointer vector");
-    psVector *psVec = psVectorAlloc(PS_TYPE_PTR, 5);
+    psVector *psVec = psVectorAlloc(5, PS_TYPE_PTR);
     printf("Vector size = %d\n", psVec->nalloc);
     printf("Vector population = %d\n", psVec->n);
@@ -52,5 +52,5 @@
         ts->y = 10.1*i;
         mySt[i] = ts;
-        psVec->vec.vp[i] = ts;
+        psVec->data.PTR[i] = ts;
         psVec->n++;
         psMemIncrRefCounter(ts);
@@ -58,5 +58,5 @@
 
     for(int i = 0; i < 5; i++) {
-        testStruct *ts = (testStruct*)psVec->vec.vp[i];
+        testStruct *ts = (testStruct*)psVec->data.PTR[i];
         printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
     }
@@ -68,5 +68,5 @@
     // Test C - Reallocate void pointer vector bigger
     printPositiveTestHeader(stdout,"psVector", "Reallocate void pointer vector bigger");
-    psVec = psVectorRealloc(psVec, 10);
+    psVec = psVectorRealloc(10, psVec);
     printf("Adding more elements to void pointer vector...\n");
     for(int i = 5; i < 10; i++) {
@@ -75,10 +75,10 @@
         ts->y = 10.1*i;
         mySt[i] = ts;
-        psVec->vec.vp[i] = ts;
+        psVec->data.PTR[i] = ts;
         psVec->n++;
         psMemIncrRefCounter(ts);
     }
     for(int i = 0; i < 10; i++) {
-        testStruct *ts = (testStruct*)psVec->vec.vp[i];
+        testStruct *ts = (testStruct*)psVec->data.PTR[i];
         printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
     }
@@ -90,7 +90,7 @@
     // Test D - Reallocate void pointer vector smaller
     printPositiveTestHeader(stdout,"psVector","Reallocate void pointer vector smaller");
-    psVec = psVectorRealloc(psVec, 3);
+    psVec = psVectorRealloc(3, psVec);
     for(int i = 0; i < 3; i++) {
-        testStruct *ts = (testStruct*)psVec->vec.vp[i];
+        testStruct *ts = (testStruct*)psVec->data.PTR[i];
         printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
     }
Index: trunk/psLib/test/collections/tst_psVector_03.c
===================================================================
--- trunk/psLib/test/collections/tst_psVector_03.c	(revision 805)
+++ trunk/psLib/test/collections/tst_psVector_03.c	(revision 831)
@@ -12,6 +12,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-02 23:29:29 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -44,5 +44,5 @@
     // Test A - Create void pointer vector
     printPositiveTestHeader(stdout,"psVector", "Create void pointer vector");
-    psVector *psVec = psVectorAlloc(PS_TYPE_PTR, 5);
+    psVector *psVec = psVectorAlloc(5, PS_TYPE_PTR);
     printf("Vector size = %d\n", psVec->nalloc);
     printf("Vector population = %d\n", psVec->n);
@@ -57,5 +57,5 @@
         ts->y = 10.1*i;
         mySt[i] = ts;
-        psVec->vec.vp[i] = ts;
+        psVec->data.PTR[i] = ts;
         psVec->n++;
         psMemIncrRefCounter(ts);
@@ -63,5 +63,5 @@
 
     for(int i = 0; i < 5; i++) {
-        testStruct *ts = (testStruct*)psVec->vec.vp[i];
+        testStruct *ts = (testStruct*)psVec->data.PTR[i];
         printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
     }
@@ -73,5 +73,5 @@
     // Test C - Reallocate void pointer vector bigger
     printPositiveTestHeader(stdout,"psVector", "Reallocate void pointer vector bigger");
-    psVec = psVectorRealloc(psVec, 10);
+    psVec = psVectorRealloc(10, psVec);
     printf("Adding more elements to void pointer vector...\n");
     for(int i = 5; i < 10; i++) {
@@ -80,10 +80,10 @@
         ts->y = 10.1*i;
         mySt[i] = ts;
-        psVec->vec.vp[i] = ts;
+        psVec->data.PTR[i] = ts;
         psVec->n++;
         psMemIncrRefCounter(ts);
     }
     for(int i = 0; i < 10; i++) {
-        testStruct *ts = (testStruct*)psVec->vec.vp[i];
+        testStruct *ts = (testStruct*)psVec->data.PTR[i];
         printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
     }
@@ -95,7 +95,7 @@
     // Test D - Reallocate void pointer vector smaller
     printPositiveTestHeader(stdout,"psVector","Reallocate void pointer vector smaller");
-    psVec = psVectorRealloc(psVec, 3);
+    psVec = psVectorRealloc(3, psVec);
     for(int i = 0; i < 3; i++) {
-        testStruct *ts = (testStruct*)psVec->vec.vp[i];
+        testStruct *ts = (testStruct*)psVec->data.PTR[i];
         printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
     }

Index: trunk/psLib/test/collections/tst_psVector_01.c
===================================================================
--- trunk/psLib/test/collections/tst_psVector_01.c	(revision 805)
+++ trunk/psLib/test/collections/tst_psVector_01.c	(revision 831)
@@ -4,14 +4,14 @@
  *
  *  This test driver contains the following tests for psVector test point 1:
  *     A)  Create INT32 vector
  *     B)  Add data to INT32 vector
  *     C)  Reallocate INT32 vector bigger
  *     D)  Reallocate INT32 vector smaller
  *     E)  Free INT32 vector
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-02 23:29:29 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -27,52 +27,52 @@
 
 
-    // Test A - Create INT32 vector
-    printPositiveTestHeader(stdout,"psVector", "Create INT32 vector");
-    psVector *psVec = psVectorAlloc(PS_TYPE_INT32, 5);
+    // Test A - Create S32 vector
+    printPositiveTestHeader(stdout,"psVector", "Create S32 vector");
+    psVector *psVec = psVectorAlloc(5, PS_TYPE_S32);
     printf("Vector size = %d\n", psVec->nalloc);
     printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Create INT32 vector", true);
+    printFooter(stdout, "psVector", "Create S32 vector", true);
 
 
     // Test B - Add data to integer vector
-    printPositiveTestHeader(stdout, "psVector", "Add data to INT32 vector");
+    printPositiveTestHeader(stdout, "psVector", "Add data to S32 vector");
     for(int i = 0; i < 5; i++) {
-        psVec->vec.i32[i] = i*10;
+        psVec->data.S32[i] = i*10;
         psVec->n++;
-        printf("Elem %d = %d\n", i, psVec->vec.i32[i]);
+        printf("Elem %d = %d\n", i, psVec->data.S32[i]);
     }
     printf("Vector size = %d\n", psVec->nalloc);
     printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Add data to INT32 vector", true);
+    printFooter(stdout, "psVector", "Add data to S32 vector", true);
 
 
-    // Test C - Reallocate INT32 vector bigger
-    printPositiveTestHeader(stdout,"psVector", "Reallocate INT32 vector bigger");
-    psVec = psVectorRealloc(psVec, 10);
-    printf("Adding more elements to INT32 vector...\n");
+    // Test C - Reallocate S32 vector bigger
+    printPositiveTestHeader(stdout,"psVector", "Reallocate S32 vector bigger");
+    psVec = psVectorRealloc(10, psVec);
+    printf("Adding more elements to S32 vector...\n");
     for(int i = 5; i < 10; i++) {
-        psVec->vec.i32[i] = i*10;
+        psVec->data.S32[i] = i*10;
         psVec->n++;
-        printf("Elem %d = %d\n", i, psVec->vec.i32[i]);
+        printf("Elem %d = %d\n", i, psVec->data.S32[i]);
     }
     printf("Vector size = %d\n", psVec->nalloc);
     printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate INT32 vector bigger", true);
+    printFooter(stdout, "psVector", "Reallocate S32 vector bigger", true);
 
 
-    // Test D - Reallocate INT32 vector smaller
-    printPositiveTestHeader(stdout,"psVector","Reallocate INT32 vector smaller");
-    psVec = psVectorRealloc(psVec, 3);
+    // Test D - Reallocate S32 vector smaller
+    printPositiveTestHeader(stdout,"psVector","Reallocate S32 vector smaller");
+    psVec = psVectorRealloc(3, psVec);
     printf("Vector size = %d\n", psVec->nalloc);
     for(int i = 0; i < 3; i++) {
-        printf("Elem %d = %d\n", i, psVec->vec.i32[i]);
+        printf("Elem %d = %d\n", i, psVec->data.S32[i]);
     }
     printf("Vector size = %d\n", psVec->nalloc);
     printf("Vector population = %d\n", psVec->n);
-    printFooter(stdout, "psVector", "Reallocate integer INT32 smaller", true);
+    printFooter(stdout, "psVector", "Reallocate integer S32 smaller", true);
 
 
-    // Test E - Free INT32 vector
-    printPositiveTestHeader(stdout, "psVector", "Free INT32 vector");
+    // Test E - Free S32 vector
+    printPositiveTestHeader(stdout, "psVector", "Free S32 vector");
     psVectorFree(psVec);
     psMemCheckLeaks(0, NULL, stdout);
@@ -81,5 +81,5 @@
         printf("ERROR: Found %d bad memory blocks\n", nBad);
     }
-    printFooter(stdout, "psVector" ,"Free INT32 vector", true);
+    printFooter(stdout, "psVector" ,"Free S32 vector", true);
 
     return 0;
@@ -4,14 +4,14 @@
  *
  *  This test driver contains the following tests for psVector test point 1:
- *     A)  Create INT32 vector
- *     B)  Add data to INT32 vector
- *     C)  Reallocate INT32 vector bigger
- *     D)  Reallocate INT32 vector smaller
- *     E)  Free INT32 vector
+ *     A)  Create S32 vector
+ *     B)  Add data to S32 vector
+ *     C)  Reallocate S32 vector bigger
+ *     D)  Reallocate S32 vector smaller
+ *     E)  Free S32 vector
  *
  *  @author  Ross Harman, MHPCC